Two methods:\n*get_tags for get tags exsiste in html page\n*scrp for scraping scrp(src,tag) have Two result:\n  -the first result scrp['txt'] = text exsiste between tags,\n  -the second result scrp['tag'] = the src (tags and text) exsiste between tags